# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['SystemHookArgs', 'SystemHook']

@pulumi.input_type
class SystemHookArgs:
    def __init__(__self__, *,
                 url: pulumi.Input[_builtins.str],
                 enable_ssl_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_update_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a SystemHook resource.
        :param pulumi.Input[_builtins.str] url: The hook URL.
        :param pulumi.Input[_builtins.bool] enable_ssl_verification: Do SSL verification when triggering the hook.
        :param pulumi.Input[_builtins.bool] merge_requests_events: Trigger hook on merge requests events.
        :param pulumi.Input[_builtins.bool] push_events: When true, the hook fires on push events.
        :param pulumi.Input[_builtins.bool] repository_update_events: Trigger hook on repository update events.
        :param pulumi.Input[_builtins.bool] tag_push_events: When true, the hook fires on new tags being pushed.
        :param pulumi.Input[_builtins.str] token: Secret token to validate received payloads; this isn't returned in the response. This attribute is not available for imported resources.
        """
        pulumi.set(__self__, "url", url)
        if enable_ssl_verification is not None:
            pulumi.set(__self__, "enable_ssl_verification", enable_ssl_verification)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if repository_update_events is not None:
            pulumi.set(__self__, "repository_update_events", repository_update_events)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        The hook URL.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do SSL verification when triggering the hook.
        """
        return pulumi.get(self, "enable_ssl_verification")

    @enable_ssl_verification.setter
    def enable_ssl_verification(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_ssl_verification", value)

    @_builtins.property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Trigger hook on merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @_builtins.property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When true, the hook fires on push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "push_events", value)

    @_builtins.property
    @pulumi.getter(name="repositoryUpdateEvents")
    def repository_update_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Trigger hook on repository update events.
        """
        return pulumi.get(self, "repository_update_events")

    @repository_update_events.setter
    def repository_update_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "repository_update_events", value)

    @_builtins.property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When true, the hook fires on new tags being pushed.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tag_push_events", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret token to validate received payloads; this isn't returned in the response. This attribute is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)


@pulumi.input_type
class _SystemHookState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_ssl_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_update_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering SystemHook resources.
        :param pulumi.Input[_builtins.str] created_at: The date and time the hook was created in ISO8601 format.
        :param pulumi.Input[_builtins.bool] enable_ssl_verification: Do SSL verification when triggering the hook.
        :param pulumi.Input[_builtins.bool] merge_requests_events: Trigger hook on merge requests events.
        :param pulumi.Input[_builtins.bool] push_events: When true, the hook fires on push events.
        :param pulumi.Input[_builtins.bool] repository_update_events: Trigger hook on repository update events.
        :param pulumi.Input[_builtins.bool] tag_push_events: When true, the hook fires on new tags being pushed.
        :param pulumi.Input[_builtins.str] token: Secret token to validate received payloads; this isn't returned in the response. This attribute is not available for imported resources.
        :param pulumi.Input[_builtins.str] url: The hook URL.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if enable_ssl_verification is not None:
            pulumi.set(__self__, "enable_ssl_verification", enable_ssl_verification)
        if merge_requests_events is not None:
            pulumi.set(__self__, "merge_requests_events", merge_requests_events)
        if push_events is not None:
            pulumi.set(__self__, "push_events", push_events)
        if repository_update_events is not None:
            pulumi.set(__self__, "repository_update_events", repository_update_events)
        if tag_push_events is not None:
            pulumi.set(__self__, "tag_push_events", tag_push_events)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time the hook was created in ISO8601 format.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Do SSL verification when triggering the hook.
        """
        return pulumi.get(self, "enable_ssl_verification")

    @enable_ssl_verification.setter
    def enable_ssl_verification(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_ssl_verification", value)

    @_builtins.property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Trigger hook on merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @merge_requests_events.setter
    def merge_requests_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "merge_requests_events", value)

    @_builtins.property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When true, the hook fires on push events.
        """
        return pulumi.get(self, "push_events")

    @push_events.setter
    def push_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "push_events", value)

    @_builtins.property
    @pulumi.getter(name="repositoryUpdateEvents")
    def repository_update_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Trigger hook on repository update events.
        """
        return pulumi.get(self, "repository_update_events")

    @repository_update_events.setter
    def repository_update_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "repository_update_events", value)

    @_builtins.property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When true, the hook fires on new tags being pushed.
        """
        return pulumi.get(self, "tag_push_events")

    @tag_push_events.setter
    def tag_push_events(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "tag_push_events", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Secret token to validate received payloads; this isn't returned in the response. This attribute is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hook URL.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("gitlab:index/systemHook:SystemHook")
class SystemHook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_ssl_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_update_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `SystemHook` resource allows to manage the lifecycle of a system hook.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/system_hooks/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.SystemHook("example",
            url="https://example.com/hook-%d",
            token="secret-token",
            push_events=True,
            tag_push_events=True,
            merge_requests_events=True,
            repository_update_events=True,
            enable_ssl_verification=True)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_system_hook`. For example:

        terraform

        import {

          to = gitlab_system_hook.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import a system hook using the hook id `{hook-id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/systemHook:SystemHook example 42
        ```

        NOTE: the `token` attribute won't be available for imported resources.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enable_ssl_verification: Do SSL verification when triggering the hook.
        :param pulumi.Input[_builtins.bool] merge_requests_events: Trigger hook on merge requests events.
        :param pulumi.Input[_builtins.bool] push_events: When true, the hook fires on push events.
        :param pulumi.Input[_builtins.bool] repository_update_events: Trigger hook on repository update events.
        :param pulumi.Input[_builtins.bool] tag_push_events: When true, the hook fires on new tags being pushed.
        :param pulumi.Input[_builtins.str] token: Secret token to validate received payloads; this isn't returned in the response. This attribute is not available for imported resources.
        :param pulumi.Input[_builtins.str] url: The hook URL.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SystemHookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `SystemHook` resource allows to manage the lifecycle of a system hook.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/system_hooks/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.SystemHook("example",
            url="https://example.com/hook-%d",
            token="secret-token",
            push_events=True,
            tag_push_events=True,
            merge_requests_events=True,
            repository_update_events=True,
            enable_ssl_verification=True)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_system_hook`. For example:

        terraform

        import {

          to = gitlab_system_hook.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import a system hook using the hook id `{hook-id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/systemHook:SystemHook example 42
        ```

        NOTE: the `token` attribute won't be available for imported resources.

        :param str resource_name: The name of the resource.
        :param SystemHookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SystemHookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_ssl_verification: Optional[pulumi.Input[_builtins.bool]] = None,
                 merge_requests_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 repository_update_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 tag_push_events: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SystemHookArgs.__new__(SystemHookArgs)

            __props__.__dict__["enable_ssl_verification"] = enable_ssl_verification
            __props__.__dict__["merge_requests_events"] = merge_requests_events
            __props__.__dict__["push_events"] = push_events
            __props__.__dict__["repository_update_events"] = repository_update_events
            __props__.__dict__["tag_push_events"] = tag_push_events
            __props__.__dict__["token"] = None if token is None else pulumi.Output.secret(token)
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["created_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(SystemHook, __self__).__init__(
            'gitlab:index/systemHook:SystemHook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            enable_ssl_verification: Optional[pulumi.Input[_builtins.bool]] = None,
            merge_requests_events: Optional[pulumi.Input[_builtins.bool]] = None,
            push_events: Optional[pulumi.Input[_builtins.bool]] = None,
            repository_update_events: Optional[pulumi.Input[_builtins.bool]] = None,
            tag_push_events: Optional[pulumi.Input[_builtins.bool]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'SystemHook':
        """
        Get an existing SystemHook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: The date and time the hook was created in ISO8601 format.
        :param pulumi.Input[_builtins.bool] enable_ssl_verification: Do SSL verification when triggering the hook.
        :param pulumi.Input[_builtins.bool] merge_requests_events: Trigger hook on merge requests events.
        :param pulumi.Input[_builtins.bool] push_events: When true, the hook fires on push events.
        :param pulumi.Input[_builtins.bool] repository_update_events: Trigger hook on repository update events.
        :param pulumi.Input[_builtins.bool] tag_push_events: When true, the hook fires on new tags being pushed.
        :param pulumi.Input[_builtins.str] token: Secret token to validate received payloads; this isn't returned in the response. This attribute is not available for imported resources.
        :param pulumi.Input[_builtins.str] url: The hook URL.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SystemHookState.__new__(_SystemHookState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["enable_ssl_verification"] = enable_ssl_verification
        __props__.__dict__["merge_requests_events"] = merge_requests_events
        __props__.__dict__["push_events"] = push_events
        __props__.__dict__["repository_update_events"] = repository_update_events
        __props__.__dict__["tag_push_events"] = tag_push_events
        __props__.__dict__["token"] = token
        __props__.__dict__["url"] = url
        return SystemHook(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time the hook was created in ISO8601 format.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="enableSslVerification")
    def enable_ssl_verification(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Do SSL verification when triggering the hook.
        """
        return pulumi.get(self, "enable_ssl_verification")

    @_builtins.property
    @pulumi.getter(name="mergeRequestsEvents")
    def merge_requests_events(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Trigger hook on merge requests events.
        """
        return pulumi.get(self, "merge_requests_events")

    @_builtins.property
    @pulumi.getter(name="pushEvents")
    def push_events(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When true, the hook fires on push events.
        """
        return pulumi.get(self, "push_events")

    @_builtins.property
    @pulumi.getter(name="repositoryUpdateEvents")
    def repository_update_events(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Trigger hook on repository update events.
        """
        return pulumi.get(self, "repository_update_events")

    @_builtins.property
    @pulumi.getter(name="tagPushEvents")
    def tag_push_events(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When true, the hook fires on new tags being pushed.
        """
        return pulumi.get(self, "tag_push_events")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Secret token to validate received payloads; this isn't returned in the response. This attribute is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The hook URL.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetClusterAgentsResult',
    'AwaitableGetClusterAgentsResult',
    'get_cluster_agents',
    'get_cluster_agents_output',
]

@pulumi.output_type
class GetClusterAgentsResult:
    """
    A collection of values returned by getClusterAgents.
    """
    def __init__(__self__, cluster_agents=None, id=None, project=None):
        if cluster_agents and not isinstance(cluster_agents, list):
            raise TypeError("Expected argument 'cluster_agents' to be a list")
        pulumi.set(__self__, "cluster_agents", cluster_agents)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)

    @_builtins.property
    @pulumi.getter(name="clusterAgents")
    def cluster_agents(self) -> Sequence['outputs.GetClusterAgentsClusterAgentResult']:
        """
        List of the registered agents.
        """
        return pulumi.get(self, "cluster_agents")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this data source. In the format \\n\\n
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        ID or full path of the project maintained by the authenticated user.
        """
        return pulumi.get(self, "project")


class AwaitableGetClusterAgentsResult(GetClusterAgentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClusterAgentsResult(
            cluster_agents=self.cluster_agents,
            id=self.id,
            project=self.project)


def get_cluster_agents(project: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClusterAgentsResult:
    """
    The `get_cluster_agents` data source retrieves details of GitLab Agents for Kubernetes in a project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/cluster_agents/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    agents = gitlab.get_cluster_agents(project="12345")
    ```


    :param _builtins.str project: ID or full path of the project maintained by the authenticated user.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getClusterAgents:getClusterAgents', __args__, opts=opts, typ=GetClusterAgentsResult).value

    return AwaitableGetClusterAgentsResult(
        cluster_agents=pulumi.get(__ret__, 'cluster_agents'),
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'))
def get_cluster_agents_output(project: Optional[pulumi.Input[_builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetClusterAgentsResult]:
    """
    The `get_cluster_agents` data source retrieves details of GitLab Agents for Kubernetes in a project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/cluster_agents/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    agents = gitlab.get_cluster_agents(project="12345")
    ```


    :param _builtins.str project: ID or full path of the project maintained by the authenticated user.
    """
    __args__ = dict()
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getClusterAgents:getClusterAgents', __args__, opts=opts, typ=GetClusterAgentsResult)
    return __ret__.apply(lambda __response__: GetClusterAgentsResult(
        cluster_agents=pulumi.get(__response__, 'cluster_agents'),
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectIssueLinkArgs', 'ProjectIssueLink']

@pulumi.input_type
class ProjectIssueLinkArgs:
    def __init__(__self__, *,
                 issue_iid: pulumi.Input[_builtins.int],
                 link_type: pulumi.Input[_builtins.str],
                 project: pulumi.Input[_builtins.str],
                 target_issue_iid: pulumi.Input[_builtins.int],
                 target_project_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a ProjectIssueLink resource.
        :param pulumi.Input[_builtins.int] issue_iid: The internal ID of a project's issue.
        :param pulumi.Input[_builtins.str] link_type: Type of the relationship. Valid values are `relates_to`, `blocks`, `is_blocked_by`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.int] target_issue_iid: The internal ID of the target issue.
        :param pulumi.Input[_builtins.str] target_project_id: The ID or URL-encoded path of the target project.
        """
        pulumi.set(__self__, "issue_iid", issue_iid)
        pulumi.set(__self__, "link_type", link_type)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "target_issue_iid", target_issue_iid)
        pulumi.set(__self__, "target_project_id", target_project_id)

    @_builtins.property
    @pulumi.getter(name="issueIid")
    def issue_iid(self) -> pulumi.Input[_builtins.int]:
        """
        The internal ID of a project's issue.
        """
        return pulumi.get(self, "issue_iid")

    @issue_iid.setter
    def issue_iid(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "issue_iid", value)

    @_builtins.property
    @pulumi.getter(name="linkType")
    def link_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of the relationship. Valid values are `relates_to`, `blocks`, `is_blocked_by`.
        """
        return pulumi.get(self, "link_type")

    @link_type.setter
    def link_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "link_type", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="targetIssueIid")
    def target_issue_iid(self) -> pulumi.Input[_builtins.int]:
        """
        The internal ID of the target issue.
        """
        return pulumi.get(self, "target_issue_iid")

    @target_issue_iid.setter
    def target_issue_iid(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "target_issue_iid", value)

    @_builtins.property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the target project.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "target_project_id", value)


@pulumi.input_type
class _ProjectIssueLinkState:
    def __init__(__self__, *,
                 issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                 issue_link_id: Optional[pulumi.Input[_builtins.int]] = None,
                 link_type: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 target_issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                 target_project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectIssueLink resources.
        :param pulumi.Input[_builtins.int] issue_iid: The internal ID of a project's issue.
        :param pulumi.Input[_builtins.int] issue_link_id: ID of an issue relationship.
        :param pulumi.Input[_builtins.str] link_type: Type of the relationship. Valid values are `relates_to`, `blocks`, `is_blocked_by`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.int] target_issue_iid: The internal ID of the target issue.
        :param pulumi.Input[_builtins.str] target_project_id: The ID or URL-encoded path of the target project.
        """
        if issue_iid is not None:
            pulumi.set(__self__, "issue_iid", issue_iid)
        if issue_link_id is not None:
            pulumi.set(__self__, "issue_link_id", issue_link_id)
        if link_type is not None:
            pulumi.set(__self__, "link_type", link_type)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if target_issue_iid is not None:
            pulumi.set(__self__, "target_issue_iid", target_issue_iid)
        if target_project_id is not None:
            pulumi.set(__self__, "target_project_id", target_project_id)

    @_builtins.property
    @pulumi.getter(name="issueIid")
    def issue_iid(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The internal ID of a project's issue.
        """
        return pulumi.get(self, "issue_iid")

    @issue_iid.setter
    def issue_iid(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "issue_iid", value)

    @_builtins.property
    @pulumi.getter(name="issueLinkId")
    def issue_link_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        ID of an issue relationship.
        """
        return pulumi.get(self, "issue_link_id")

    @issue_link_id.setter
    def issue_link_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "issue_link_id", value)

    @_builtins.property
    @pulumi.getter(name="linkType")
    def link_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the relationship. Valid values are `relates_to`, `blocks`, `is_blocked_by`.
        """
        return pulumi.get(self, "link_type")

    @link_type.setter
    def link_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "link_type", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="targetIssueIid")
    def target_issue_iid(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The internal ID of the target issue.
        """
        return pulumi.get(self, "target_issue_iid")

    @target_issue_iid.setter
    def target_issue_iid(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "target_issue_iid", value)

    @_builtins.property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the target project.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_project_id", value)


@pulumi.type_token("gitlab:index/projectIssueLink:ProjectIssueLink")
class ProjectIssueLink(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                 link_type: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 target_issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                 target_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectIssueLink` resource allows to manage the lifecycle of project issue links.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/issue_links/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Create a project
        example = gitlab.Project("example",
            name="example",
            description="An example project",
            visibility_level="public")
        # Create source issue
        source = gitlab.ProjectIssue("source",
            project=example.id,
            title="Source Issue")
        # Create target issue
        target = gitlab.ProjectIssue("target",
            project=example.id,
            title="Target Issue")
        # Link issues with "relates_to" link type (default)
        relates_to = gitlab.ProjectIssueLink("relates_to",
            project=example.id,
            issue_iid=source.iid,
            target_project_id=example.id,
            target_issue_iid=target.iid,
            link_type="relates_to")
        # Cross-project linking example
        other_project = gitlab.Project("other_project",
            name="other_project",
            description="Another project for cross-project linking")
        cross_target = gitlab.ProjectIssue("cross_target",
            project=other_project.id,
            title="Cross-Project Target Issue")
        cross_project_relates_to = gitlab.ProjectIssueLink("cross_project_relates_to",
            project=example.id,
            issue_iid=source.iid,
            target_project_id=other_project.id,
            target_issue_iid=cross_target.iid,
            link_type="relates_to")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_issue_link`. For example:

        terraform

        import {

          to = gitlab_project_issue_link.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import this resource with an id made up of `{project-id}:{source-issue-iid}:{target-issue-iid}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectIssueLink:ProjectIssueLink example 42:1001:1002
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] issue_iid: The internal ID of a project's issue.
        :param pulumi.Input[_builtins.str] link_type: Type of the relationship. Valid values are `relates_to`, `blocks`, `is_blocked_by`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.int] target_issue_iid: The internal ID of the target issue.
        :param pulumi.Input[_builtins.str] target_project_id: The ID or URL-encoded path of the target project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectIssueLinkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectIssueLink` resource allows to manage the lifecycle of project issue links.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/issue_links/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # Create a project
        example = gitlab.Project("example",
            name="example",
            description="An example project",
            visibility_level="public")
        # Create source issue
        source = gitlab.ProjectIssue("source",
            project=example.id,
            title="Source Issue")
        # Create target issue
        target = gitlab.ProjectIssue("target",
            project=example.id,
            title="Target Issue")
        # Link issues with "relates_to" link type (default)
        relates_to = gitlab.ProjectIssueLink("relates_to",
            project=example.id,
            issue_iid=source.iid,
            target_project_id=example.id,
            target_issue_iid=target.iid,
            link_type="relates_to")
        # Cross-project linking example
        other_project = gitlab.Project("other_project",
            name="other_project",
            description="Another project for cross-project linking")
        cross_target = gitlab.ProjectIssue("cross_target",
            project=other_project.id,
            title="Cross-Project Target Issue")
        cross_project_relates_to = gitlab.ProjectIssueLink("cross_project_relates_to",
            project=example.id,
            issue_iid=source.iid,
            target_project_id=other_project.id,
            target_issue_iid=cross_target.iid,
            link_type="relates_to")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_issue_link`. For example:

        terraform

        import {

          to = gitlab_project_issue_link.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import this resource with an id made up of `{project-id}:{source-issue-iid}:{target-issue-iid}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectIssueLink:ProjectIssueLink example 42:1001:1002
        ```

        :param str resource_name: The name of the resource.
        :param ProjectIssueLinkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectIssueLinkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                 link_type: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 target_issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                 target_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectIssueLinkArgs.__new__(ProjectIssueLinkArgs)

            if issue_iid is None and not opts.urn:
                raise TypeError("Missing required property 'issue_iid'")
            __props__.__dict__["issue_iid"] = issue_iid
            if link_type is None and not opts.urn:
                raise TypeError("Missing required property 'link_type'")
            __props__.__dict__["link_type"] = link_type
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if target_issue_iid is None and not opts.urn:
                raise TypeError("Missing required property 'target_issue_iid'")
            __props__.__dict__["target_issue_iid"] = target_issue_iid
            if target_project_id is None and not opts.urn:
                raise TypeError("Missing required property 'target_project_id'")
            __props__.__dict__["target_project_id"] = target_project_id
            __props__.__dict__["issue_link_id"] = None
        super(ProjectIssueLink, __self__).__init__(
            'gitlab:index/projectIssueLink:ProjectIssueLink',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
            issue_link_id: Optional[pulumi.Input[_builtins.int]] = None,
            link_type: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            target_issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
            target_project_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectIssueLink':
        """
        Get an existing ProjectIssueLink resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] issue_iid: The internal ID of a project's issue.
        :param pulumi.Input[_builtins.int] issue_link_id: ID of an issue relationship.
        :param pulumi.Input[_builtins.str] link_type: Type of the relationship. Valid values are `relates_to`, `blocks`, `is_blocked_by`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.int] target_issue_iid: The internal ID of the target issue.
        :param pulumi.Input[_builtins.str] target_project_id: The ID or URL-encoded path of the target project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectIssueLinkState.__new__(_ProjectIssueLinkState)

        __props__.__dict__["issue_iid"] = issue_iid
        __props__.__dict__["issue_link_id"] = issue_link_id
        __props__.__dict__["link_type"] = link_type
        __props__.__dict__["project"] = project
        __props__.__dict__["target_issue_iid"] = target_issue_iid
        __props__.__dict__["target_project_id"] = target_project_id
        return ProjectIssueLink(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="issueIid")
    def issue_iid(self) -> pulumi.Output[_builtins.int]:
        """
        The internal ID of a project's issue.
        """
        return pulumi.get(self, "issue_iid")

    @_builtins.property
    @pulumi.getter(name="issueLinkId")
    def issue_link_id(self) -> pulumi.Output[_builtins.int]:
        """
        ID of an issue relationship.
        """
        return pulumi.get(self, "issue_link_id")

    @_builtins.property
    @pulumi.getter(name="linkType")
    def link_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the relationship. Valid values are `relates_to`, `blocks`, `is_blocked_by`.
        """
        return pulumi.get(self, "link_type")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="targetIssueIid")
    def target_issue_iid(self) -> pulumi.Output[_builtins.int]:
        """
        The internal ID of the target issue.
        """
        return pulumi.get(self, "target_issue_iid")

    @_builtins.property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the target project.
        """
        return pulumi.get(self, "target_project_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectMirrorArgs', 'ProjectMirror']

@pulumi.input_type
class ProjectMirrorArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 url: pulumi.Input[_builtins.str],
                 auth_method: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_divergent_refs: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 only_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ProjectMirror resource.
        :param pulumi.Input[_builtins.str] project: The id of the project.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to be mirrored.
        :param pulumi.Input[_builtins.str] auth_method: Determines the mirror authentication method. Valid values are: `ssh_public_key`, `password`.
        :param pulumi.Input[_builtins.bool] enabled: Determines if the mirror is enabled.
        :param pulumi.Input[_builtins.bool] keep_divergent_refs: Determines if divergent refs are skipped.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Contains a regular expression. Only branches with names matching the regex are mirrored. Requires only*protected*branches to be disabled. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] only_protected_branches: Determines if only protected branches are mirrored.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "url", url)
        if auth_method is not None:
            pulumi.set(__self__, "auth_method", auth_method)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if keep_divergent_refs is not None:
            pulumi.set(__self__, "keep_divergent_refs", keep_divergent_refs)
        if mirror_branch_regex is not None:
            pulumi.set(__self__, "mirror_branch_regex", mirror_branch_regex)
        if only_protected_branches is not None:
            pulumi.set(__self__, "only_protected_branches", only_protected_branches)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        The URL of the remote repository to be mirrored.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the mirror authentication method. Valid values are: `ssh_public_key`, `password`.
        """
        return pulumi.get(self, "auth_method")

    @auth_method.setter
    def auth_method(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_method", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Determines if the mirror is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="keepDivergentRefs")
    def keep_divergent_refs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Determines if divergent refs are skipped.
        """
        return pulumi.get(self, "keep_divergent_refs")

    @keep_divergent_refs.setter
    def keep_divergent_refs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_divergent_refs", value)

    @_builtins.property
    @pulumi.getter(name="mirrorBranchRegex")
    def mirror_branch_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Contains a regular expression. Only branches with names matching the regex are mirrored. Requires only*protected*branches to be disabled. Premium and Ultimate only.
        """
        return pulumi.get(self, "mirror_branch_regex")

    @mirror_branch_regex.setter
    def mirror_branch_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mirror_branch_regex", value)

    @_builtins.property
    @pulumi.getter(name="onlyProtectedBranches")
    def only_protected_branches(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Determines if only protected branches are mirrored.
        """
        return pulumi.get(self, "only_protected_branches")

    @only_protected_branches.setter
    def only_protected_branches(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_protected_branches", value)


@pulumi.input_type
class _ProjectMirrorState:
    def __init__(__self__, *,
                 auth_method: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_divergent_refs: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 mirror_id: Optional[pulumi.Input[_builtins.int]] = None,
                 only_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectMirror resources.
        :param pulumi.Input[_builtins.str] auth_method: Determines the mirror authentication method. Valid values are: `ssh_public_key`, `password`.
        :param pulumi.Input[_builtins.bool] enabled: Determines if the mirror is enabled.
        :param pulumi.Input[_builtins.bool] keep_divergent_refs: Determines if divergent refs are skipped.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Contains a regular expression. Only branches with names matching the regex are mirrored. Requires only*protected*branches to be disabled. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] mirror_id: Mirror ID.
        :param pulumi.Input[_builtins.bool] only_protected_branches: Determines if only protected branches are mirrored.
        :param pulumi.Input[_builtins.str] project: The id of the project.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to be mirrored.
        """
        if auth_method is not None:
            pulumi.set(__self__, "auth_method", auth_method)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if keep_divergent_refs is not None:
            pulumi.set(__self__, "keep_divergent_refs", keep_divergent_refs)
        if mirror_branch_regex is not None:
            pulumi.set(__self__, "mirror_branch_regex", mirror_branch_regex)
        if mirror_id is not None:
            pulumi.set(__self__, "mirror_id", mirror_id)
        if only_protected_branches is not None:
            pulumi.set(__self__, "only_protected_branches", only_protected_branches)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the mirror authentication method. Valid values are: `ssh_public_key`, `password`.
        """
        return pulumi.get(self, "auth_method")

    @auth_method.setter
    def auth_method(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_method", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Determines if the mirror is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="keepDivergentRefs")
    def keep_divergent_refs(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Determines if divergent refs are skipped.
        """
        return pulumi.get(self, "keep_divergent_refs")

    @keep_divergent_refs.setter
    def keep_divergent_refs(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_divergent_refs", value)

    @_builtins.property
    @pulumi.getter(name="mirrorBranchRegex")
    def mirror_branch_regex(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Contains a regular expression. Only branches with names matching the regex are mirrored. Requires only*protected*branches to be disabled. Premium and Ultimate only.
        """
        return pulumi.get(self, "mirror_branch_regex")

    @mirror_branch_regex.setter
    def mirror_branch_regex(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mirror_branch_regex", value)

    @_builtins.property
    @pulumi.getter(name="mirrorId")
    def mirror_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Mirror ID.
        """
        return pulumi.get(self, "mirror_id")

    @mirror_id.setter
    def mirror_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "mirror_id", value)

    @_builtins.property
    @pulumi.getter(name="onlyProtectedBranches")
    def only_protected_branches(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Determines if only protected branches are mirrored.
        """
        return pulumi.get(self, "only_protected_branches")

    @only_protected_branches.setter
    def only_protected_branches(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "only_protected_branches", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the remote repository to be mirrored.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("gitlab:index/projectMirror:ProjectMirror")
class ProjectMirror(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_method: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_divergent_refs: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 only_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectMirror` resource manages the lifecycle of a project mirror.

        This is for *pushing* changes to a remote repository. *Pull Mirroring* can be configured with the ProjectPullMirror resource.

        > **Warning** By default, the provider sets the `keep_divergent_refs` argument to `True`.
           If you manually set `keep_divergent_refs` to `False`, GitLab mirroring removes branches in the target that aren't in the source.
           This action can result in unexpected branch deletions.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/remote_mirrors/)

        This resource is deprecated in favor of `ProjectPushMirror` which is a rename. The alias will be removed in version 19.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.ProjectMirror("foo",
            project="1",
            url="https://username:password@github.com/org/repository.git")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_mirror`. For example:

        terraform

        import {

          to = gitlab_project_mirror.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project mirror can be imported using an id made up of `project_id:mirror_id`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectMirror:ProjectMirror foo "12345:1337"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_method: Determines the mirror authentication method. Valid values are: `ssh_public_key`, `password`.
        :param pulumi.Input[_builtins.bool] enabled: Determines if the mirror is enabled.
        :param pulumi.Input[_builtins.bool] keep_divergent_refs: Determines if divergent refs are skipped.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Contains a regular expression. Only branches with names matching the regex are mirrored. Requires only*protected*branches to be disabled. Premium and Ultimate only.
        :param pulumi.Input[_builtins.bool] only_protected_branches: Determines if only protected branches are mirrored.
        :param pulumi.Input[_builtins.str] project: The id of the project.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to be mirrored.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectMirrorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectMirror` resource manages the lifecycle of a project mirror.

        This is for *pushing* changes to a remote repository. *Pull Mirroring* can be configured with the ProjectPullMirror resource.

        > **Warning** By default, the provider sets the `keep_divergent_refs` argument to `True`.
           If you manually set `keep_divergent_refs` to `False`, GitLab mirroring removes branches in the target that aren't in the source.
           This action can result in unexpected branch deletions.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/remote_mirrors/)

        This resource is deprecated in favor of `ProjectPushMirror` which is a rename. The alias will be removed in version 19.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.ProjectMirror("foo",
            project="1",
            url="https://username:password@github.com/org/repository.git")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_mirror`. For example:

        terraform

        import {

          to = gitlab_project_mirror.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab project mirror can be imported using an id made up of `project_id:mirror_id`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectMirror:ProjectMirror foo "12345:1337"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectMirrorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectMirrorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_method: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_divergent_refs: Optional[pulumi.Input[_builtins.bool]] = None,
                 mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
                 only_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectMirrorArgs.__new__(ProjectMirrorArgs)

            __props__.__dict__["auth_method"] = auth_method
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["keep_divergent_refs"] = keep_divergent_refs
            __props__.__dict__["mirror_branch_regex"] = mirror_branch_regex
            __props__.__dict__["only_protected_branches"] = only_protected_branches
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = None if url is None else pulumi.Output.secret(url)
            __props__.__dict__["mirror_id"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["url"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectMirror, __self__).__init__(
            'gitlab:index/projectMirror:ProjectMirror',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_method: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            keep_divergent_refs: Optional[pulumi.Input[_builtins.bool]] = None,
            mirror_branch_regex: Optional[pulumi.Input[_builtins.str]] = None,
            mirror_id: Optional[pulumi.Input[_builtins.int]] = None,
            only_protected_branches: Optional[pulumi.Input[_builtins.bool]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectMirror':
        """
        Get an existing ProjectMirror resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_method: Determines the mirror authentication method. Valid values are: `ssh_public_key`, `password`.
        :param pulumi.Input[_builtins.bool] enabled: Determines if the mirror is enabled.
        :param pulumi.Input[_builtins.bool] keep_divergent_refs: Determines if divergent refs are skipped.
        :param pulumi.Input[_builtins.str] mirror_branch_regex: Contains a regular expression. Only branches with names matching the regex are mirrored. Requires only*protected*branches to be disabled. Premium and Ultimate only.
        :param pulumi.Input[_builtins.int] mirror_id: Mirror ID.
        :param pulumi.Input[_builtins.bool] only_protected_branches: Determines if only protected branches are mirrored.
        :param pulumi.Input[_builtins.str] project: The id of the project.
        :param pulumi.Input[_builtins.str] url: The URL of the remote repository to be mirrored.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectMirrorState.__new__(_ProjectMirrorState)

        __props__.__dict__["auth_method"] = auth_method
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["keep_divergent_refs"] = keep_divergent_refs
        __props__.__dict__["mirror_branch_regex"] = mirror_branch_regex
        __props__.__dict__["mirror_id"] = mirror_id
        __props__.__dict__["only_protected_branches"] = only_protected_branches
        __props__.__dict__["project"] = project
        __props__.__dict__["url"] = url
        return ProjectMirror(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> pulumi.Output[_builtins.str]:
        """
        Determines the mirror authentication method. Valid values are: `ssh_public_key`, `password`.
        """
        return pulumi.get(self, "auth_method")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Determines if the mirror is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="keepDivergentRefs")
    def keep_divergent_refs(self) -> pulumi.Output[_builtins.bool]:
        """
        Determines if divergent refs are skipped.
        """
        return pulumi.get(self, "keep_divergent_refs")

    @_builtins.property
    @pulumi.getter(name="mirrorBranchRegex")
    def mirror_branch_regex(self) -> pulumi.Output[_builtins.str]:
        """
        Contains a regular expression. Only branches with names matching the regex are mirrored. Requires only*protected*branches to be disabled. Premium and Ultimate only.
        """
        return pulumi.get(self, "mirror_branch_regex")

    @_builtins.property
    @pulumi.getter(name="mirrorId")
    def mirror_id(self) -> pulumi.Output[_builtins.int]:
        """
        Mirror ID.
        """
        return pulumi.get(self, "mirror_id")

    @_builtins.property
    @pulumi.getter(name="onlyProtectedBranches")
    def only_protected_branches(self) -> pulumi.Output[_builtins.bool]:
        """
        Determines if only protected branches are mirrored.
        """
        return pulumi.get(self, "only_protected_branches")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the remote repository to be mirrored.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectIssueLabelEventsResult',
    'AwaitableGetProjectIssueLabelEventsResult',
    'get_project_issue_label_events',
    'get_project_issue_label_events_output',
]

@pulumi.output_type
class GetProjectIssueLabelEventsResult:
    """
    A collection of values returned by getProjectIssueLabelEvents.
    """
    def __init__(__self__, events=None, id=None, issue_iid=None, pages_returned=None, project=None):
        if events and not isinstance(events, list):
            raise TypeError("Expected argument 'events' to be a list")
        pulumi.set(__self__, "events", events)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issue_iid and not isinstance(issue_iid, int):
            raise TypeError("Expected argument 'issue_iid' to be a int")
        pulumi.set(__self__, "issue_iid", issue_iid)
        if pages_returned and not isinstance(pages_returned, int):
            raise TypeError("Expected argument 'pages_returned' to be a int")
        pulumi.set(__self__, "pages_returned", pages_returned)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)

    @_builtins.property
    @pulumi.getter
    def events(self) -> Sequence['outputs.GetProjectIssueLabelEventsEventResult']:
        """
        List of label events for the issue.
        """
        return pulumi.get(self, "events")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="issueIid")
    def issue_iid(self) -> _builtins.int:
        """
        The internal ID of the issue.
        """
        return pulumi.get(self, "issue_iid")

    @_builtins.property
    @pulumi.getter(name="pagesReturned")
    def pages_returned(self) -> Optional[_builtins.int]:
        """
        Number of pages to return. Default is 1.
        """
        return pulumi.get(self, "pages_returned")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or full path of the project.
        """
        return pulumi.get(self, "project")


class AwaitableGetProjectIssueLabelEventsResult(GetProjectIssueLabelEventsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectIssueLabelEventsResult(
            events=self.events,
            id=self.id,
            issue_iid=self.issue_iid,
            pages_returned=self.pages_returned,
            project=self.project)


def get_project_issue_label_events(issue_iid: Optional[_builtins.int] = None,
                                   pages_returned: Optional[_builtins.int] = None,
                                   project: Optional[_builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectIssueLabelEventsResult:
    """
    The `get_project_issue_label_events` data source retrieves label events for a specific GitLab project issue.

    **Upstream API**: [GitLab Resource Label Events API docs](https://docs.gitlab.com/api/resource_label_events/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_project_issue_label_events(project="my-group/my-project",
        issue_iid=42)
    ```


    :param _builtins.int issue_iid: The internal ID of the issue.
    :param _builtins.int pages_returned: Number of pages to return. Default is 1.
    :param _builtins.str project: The ID or full path of the project.
    """
    __args__ = dict()
    __args__['issueIid'] = issue_iid
    __args__['pagesReturned'] = pages_returned
    __args__['project'] = project
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectIssueLabelEvents:getProjectIssueLabelEvents', __args__, opts=opts, typ=GetProjectIssueLabelEventsResult).value

    return AwaitableGetProjectIssueLabelEventsResult(
        events=pulumi.get(__ret__, 'events'),
        id=pulumi.get(__ret__, 'id'),
        issue_iid=pulumi.get(__ret__, 'issue_iid'),
        pages_returned=pulumi.get(__ret__, 'pages_returned'),
        project=pulumi.get(__ret__, 'project'))
def get_project_issue_label_events_output(issue_iid: Optional[pulumi.Input[_builtins.int]] = None,
                                          pages_returned: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                          project: Optional[pulumi.Input[_builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectIssueLabelEventsResult]:
    """
    The `get_project_issue_label_events` data source retrieves label events for a specific GitLab project issue.

    **Upstream API**: [GitLab Resource Label Events API docs](https://docs.gitlab.com/api/resource_label_events/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_project_issue_label_events(project="my-group/my-project",
        issue_iid=42)
    ```


    :param _builtins.int issue_iid: The internal ID of the issue.
    :param _builtins.int pages_returned: Number of pages to return. Default is 1.
    :param _builtins.str project: The ID or full path of the project.
    """
    __args__ = dict()
    __args__['issueIid'] = issue_iid
    __args__['pagesReturned'] = pages_returned
    __args__['project'] = project
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectIssueLabelEvents:getProjectIssueLabelEvents', __args__, opts=opts, typ=GetProjectIssueLabelEventsResult)
    return __ret__.apply(lambda __response__: GetProjectIssueLabelEventsResult(
        events=pulumi.get(__response__, 'events'),
        id=pulumi.get(__response__, 'id'),
        issue_iid=pulumi.get(__response__, 'issue_iid'),
        pages_returned=pulumi.get(__response__, 'pages_returned'),
        project=pulumi.get(__response__, 'project')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSecurityPolicyDocumentResult',
    'AwaitableGetSecurityPolicyDocumentResult',
    'get_security_policy_document',
    'get_security_policy_document_output',
]

@pulumi.output_type
class GetSecurityPolicyDocumentResult:
    """
    A collection of values returned by getSecurityPolicyDocument.
    """
    def __init__(__self__, id=None, scan_execution_policies=None, yaml=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if scan_execution_policies and not isinstance(scan_execution_policies, list):
            raise TypeError("Expected argument 'scan_execution_policies' to be a list")
        pulumi.set(__self__, "scan_execution_policies", scan_execution_policies)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Unique identifier for this policy document (hash of generated YAML).
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="scanExecutionPolicies")
    def scan_execution_policies(self) -> Optional[Sequence['outputs.GetSecurityPolicyDocumentScanExecutionPolicyResult']]:
        """
        Scan execution policy configuration. Multiple policies can be specified.
        """
        return pulumi.get(self, "scan_execution_policies")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        The generated policy document in YAML format, ready to write to `.gitlab/security-policies/policy.yml`.
        """
        return pulumi.get(self, "yaml")


class AwaitableGetSecurityPolicyDocumentResult(GetSecurityPolicyDocumentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityPolicyDocumentResult(
            id=self.id,
            scan_execution_policies=self.scan_execution_policies,
            yaml=self.yaml)


def get_security_policy_document(scan_execution_policies: Optional[Sequence[Union['GetSecurityPolicyDocumentScanExecutionPolicyArgs', 'GetSecurityPolicyDocumentScanExecutionPolicyArgsDict']]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityPolicyDocumentResult:
    """
    Generates a GitLab security policy YAML document from structured configuration.
    This data source performs pure transformation without any API calls.

    **Upstream API**: [GitLab Security Policies Documentation](https://docs.gitlab.com/ee/user/application_security/policies/scan_execution_policies/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    # Use this with `gitlab_repository_file` to manage your policies using native HCL
    scan = gitlab.get_security_policy_document(scan_execution_policies=[{
        "name": "Basic SAST Policy",
        "enabled": True,
        "rules": [{
            "type": "pipeline",
            "branch_type": "all",
        }],
        "actions": [{
            "scan": "sast",
        }],
    }])
    # See `gitlab_project_security_policy_attachment` or `gitlab_group_security_policy_attachment`
    # for how to link a security policy project to a project or group.
    policy = gitlab.RepositoryFile("policy",
        project="1234",
        ref="main",
        file_path=".gitlab/security-policies/policy.yml",
        content=scan.yaml)
    ```


    :param Sequence[Union['GetSecurityPolicyDocumentScanExecutionPolicyArgs', 'GetSecurityPolicyDocumentScanExecutionPolicyArgsDict']] scan_execution_policies: Scan execution policy configuration. Multiple policies can be specified.
    """
    __args__ = dict()
    __args__['scanExecutionPolicies'] = scan_execution_policies
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getSecurityPolicyDocument:getSecurityPolicyDocument', __args__, opts=opts, typ=GetSecurityPolicyDocumentResult).value

    return AwaitableGetSecurityPolicyDocumentResult(
        id=pulumi.get(__ret__, 'id'),
        scan_execution_policies=pulumi.get(__ret__, 'scan_execution_policies'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_security_policy_document_output(scan_execution_policies: Optional[pulumi.Input[Optional[Sequence[Union['GetSecurityPolicyDocumentScanExecutionPolicyArgs', 'GetSecurityPolicyDocumentScanExecutionPolicyArgsDict']]]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecurityPolicyDocumentResult]:
    """
    Generates a GitLab security policy YAML document from structured configuration.
    This data source performs pure transformation without any API calls.

    **Upstream API**: [GitLab Security Policies Documentation](https://docs.gitlab.com/ee/user/application_security/policies/scan_execution_policies/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    # Use this with `gitlab_repository_file` to manage your policies using native HCL
    scan = gitlab.get_security_policy_document(scan_execution_policies=[{
        "name": "Basic SAST Policy",
        "enabled": True,
        "rules": [{
            "type": "pipeline",
            "branch_type": "all",
        }],
        "actions": [{
            "scan": "sast",
        }],
    }])
    # See `gitlab_project_security_policy_attachment` or `gitlab_group_security_policy_attachment`
    # for how to link a security policy project to a project or group.
    policy = gitlab.RepositoryFile("policy",
        project="1234",
        ref="main",
        file_path=".gitlab/security-policies/policy.yml",
        content=scan.yaml)
    ```


    :param Sequence[Union['GetSecurityPolicyDocumentScanExecutionPolicyArgs', 'GetSecurityPolicyDocumentScanExecutionPolicyArgsDict']] scan_execution_policies: Scan execution policy configuration. Multiple policies can be specified.
    """
    __args__ = dict()
    __args__['scanExecutionPolicies'] = scan_execution_policies
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getSecurityPolicyDocument:getSecurityPolicyDocument', __args__, opts=opts, typ=GetSecurityPolicyDocumentResult)
    return __ret__.apply(lambda __response__: GetSecurityPolicyDocumentResult(
        id=pulumi.get(__response__, 'id'),
        scan_execution_policies=pulumi.get(__response__, 'scan_execution_policies'),
        yaml=pulumi.get(__response__, 'yaml')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectSecureFileResult',
    'AwaitableGetProjectSecureFileResult',
    'get_project_secure_file',
    'get_project_secure_file_output',
]

@pulumi.output_type
class GetProjectSecureFileResult:
    """
    A collection of values returned by getProjectSecureFile.
    """
    def __init__(__self__, checksum=None, checksum_algorithm=None, content=None, created_at=None, expires_at=None, id=None, metadata=None, name=None, project=None, secure_file_id=None):
        if checksum and not isinstance(checksum, str):
            raise TypeError("Expected argument 'checksum' to be a str")
        pulumi.set(__self__, "checksum", checksum)
        if checksum_algorithm and not isinstance(checksum_algorithm, str):
            raise TypeError("Expected argument 'checksum_algorithm' to be a str")
        pulumi.set(__self__, "checksum_algorithm", checksum_algorithm)
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if expires_at and not isinstance(expires_at, str):
            raise TypeError("Expected argument 'expires_at' to be a str")
        pulumi.set(__self__, "expires_at", expires_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if metadata and not isinstance(metadata, dict):
            raise TypeError("Expected argument 'metadata' to be a dict")
        pulumi.set(__self__, "metadata", metadata)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if secure_file_id and not isinstance(secure_file_id, int):
            raise TypeError("Expected argument 'secure_file_id' to be a int")
        pulumi.set(__self__, "secure_file_id", secure_file_id)

    @_builtins.property
    @pulumi.getter
    def checksum(self) -> _builtins.str:
        """
        The checksum of the file
        """
        return pulumi.get(self, "checksum")

    @_builtins.property
    @pulumi.getter(name="checksumAlgorithm")
    def checksum_algorithm(self) -> _builtins.str:
        """
        The checksum algorithm used
        """
        return pulumi.get(self, "checksum_algorithm")

    @_builtins.property
    @pulumi.getter
    def content(self) -> _builtins.str:
        """
        The contents of the secure file
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        The time the secure file was uploaded
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> _builtins.str:
        """
        The time the secure file will expire
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this data source. In the format `<project:id>`
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> 'outputs.GetProjectSecureFileMetadataResult':
        """
        metadata returned by the gitlab api about the secure file
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name for the secure file, unique per project
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or full path of the project the secure file resides.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="secureFileId")
    def secure_file_id(self) -> _builtins.int:
        """
        The id of the secure file in gitlab
        """
        return pulumi.get(self, "secure_file_id")


class AwaitableGetProjectSecureFileResult(GetProjectSecureFileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectSecureFileResult(
            checksum=self.checksum,
            checksum_algorithm=self.checksum_algorithm,
            content=self.content,
            created_at=self.created_at,
            expires_at=self.expires_at,
            id=self.id,
            metadata=self.metadata,
            name=self.name,
            project=self.project,
            secure_file_id=self.secure_file_id)


def get_project_secure_file(name: Optional[_builtins.str] = None,
                            project: Optional[_builtins.str] = None,
                            secure_file_id: Optional[_builtins.int] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectSecureFileResult:
    """
    The `ProjectSecureFile` data source allows the contents of a secure file to be retrieved by either Name or ID.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/secure_files/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    by_id = gitlab.get_project_secure_file(project="123",
        secure_file_id=123)
    by_name = gitlab.get_project_secure_file(project="123",
        name="secret.pem")
    ```


    :param _builtins.str name: The name for the secure file, unique per project
    :param _builtins.str project: The ID or full path of the project the secure file resides.
    :param _builtins.int secure_file_id: The id of the secure file in gitlab
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['project'] = project
    __args__['secureFileId'] = secure_file_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectSecureFile:getProjectSecureFile', __args__, opts=opts, typ=GetProjectSecureFileResult).value

    return AwaitableGetProjectSecureFileResult(
        checksum=pulumi.get(__ret__, 'checksum'),
        checksum_algorithm=pulumi.get(__ret__, 'checksum_algorithm'),
        content=pulumi.get(__ret__, 'content'),
        created_at=pulumi.get(__ret__, 'created_at'),
        expires_at=pulumi.get(__ret__, 'expires_at'),
        id=pulumi.get(__ret__, 'id'),
        metadata=pulumi.get(__ret__, 'metadata'),
        name=pulumi.get(__ret__, 'name'),
        project=pulumi.get(__ret__, 'project'),
        secure_file_id=pulumi.get(__ret__, 'secure_file_id'))
def get_project_secure_file_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   project: Optional[pulumi.Input[_builtins.str]] = None,
                                   secure_file_id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectSecureFileResult]:
    """
    The `ProjectSecureFile` data source allows the contents of a secure file to be retrieved by either Name or ID.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/secure_files/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    by_id = gitlab.get_project_secure_file(project="123",
        secure_file_id=123)
    by_name = gitlab.get_project_secure_file(project="123",
        name="secret.pem")
    ```


    :param _builtins.str name: The name for the secure file, unique per project
    :param _builtins.str project: The ID or full path of the project the secure file resides.
    :param _builtins.int secure_file_id: The id of the secure file in gitlab
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['project'] = project
    __args__['secureFileId'] = secure_file_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectSecureFile:getProjectSecureFile', __args__, opts=opts, typ=GetProjectSecureFileResult)
    return __ret__.apply(lambda __response__: GetProjectSecureFileResult(
        checksum=pulumi.get(__response__, 'checksum'),
        checksum_algorithm=pulumi.get(__response__, 'checksum_algorithm'),
        content=pulumi.get(__response__, 'content'),
        created_at=pulumi.get(__response__, 'created_at'),
        expires_at=pulumi.get(__response__, 'expires_at'),
        id=pulumi.get(__response__, 'id'),
        metadata=pulumi.get(__response__, 'metadata'),
        name=pulumi.get(__response__, 'name'),
        project=pulumi.get(__response__, 'project'),
        secure_file_id=pulumi.get(__response__, 'secure_file_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserAvatarArgs', 'UserAvatar']

@pulumi.input_type
class UserAvatarArgs:
    def __init__(__self__, *,
                 avatar: pulumi.Input[_builtins.str],
                 user_id: pulumi.Input[_builtins.int],
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a UserAvatar resource.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: the avatar is not available for imported resources.
        :param pulumi.Input[_builtins.int] user_id: The ID of the user.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image.  This is used to track changes to the avatar image if the image contents change but the image name remains the same. Use `filesha256("path/to/avatar.png")` whenever possible.
        :param pulumi.Input[_builtins.str] token: The access token of the user. If this field is omitted, a GitLab token with administrator scope is required to manage the avatar for the specified user. **Note**: the token is not available for imported resources.
        """
        pulumi.set(__self__, "avatar", avatar)
        pulumi.set(__self__, "user_id", user_id)
        if avatar_hash is not None:
            pulumi.set(__self__, "avatar_hash", avatar_hash)
        if token is not None:
            pulumi.set(__self__, "token", token)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> pulumi.Input[_builtins.str]:
        """
        A local path to the avatar image to upload. **Note**: the avatar is not available for imported resources.
        """
        return pulumi.get(self, "avatar")

    @avatar.setter
    def avatar(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "avatar", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[_builtins.int]:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "user_id", value)

    @_builtins.property
    @pulumi.getter(name="avatarHash")
    def avatar_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hash of the avatar image.  This is used to track changes to the avatar image if the image contents change but the image name remains the same. Use `filesha256("path/to/avatar.png")` whenever possible.
        """
        return pulumi.get(self, "avatar_hash")

    @avatar_hash.setter
    def avatar_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar_hash", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access token of the user. If this field is omitted, a GitLab token with administrator scope is required to manage the avatar for the specified user. **Note**: the token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)


@pulumi.input_type
class _UserAvatarState:
    def __init__(__self__, *,
                 avatar: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_url: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering UserAvatar resources.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: the avatar is not available for imported resources.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image.  This is used to track changes to the avatar image if the image contents change but the image name remains the same. Use `filesha256("path/to/avatar.png")` whenever possible.
        :param pulumi.Input[_builtins.str] avatar_url: The URL of the avatar image.
        :param pulumi.Input[_builtins.str] token: The access token of the user. If this field is omitted, a GitLab token with administrator scope is required to manage the avatar for the specified user. **Note**: the token is not available for imported resources.
        :param pulumi.Input[_builtins.int] user_id: The ID of the user.
        """
        if avatar is not None:
            pulumi.set(__self__, "avatar", avatar)
        if avatar_hash is not None:
            pulumi.set(__self__, "avatar_hash", avatar_hash)
        if avatar_url is not None:
            pulumi.set(__self__, "avatar_url", avatar_url)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A local path to the avatar image to upload. **Note**: the avatar is not available for imported resources.
        """
        return pulumi.get(self, "avatar")

    @avatar.setter
    def avatar(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar", value)

    @_builtins.property
    @pulumi.getter(name="avatarHash")
    def avatar_hash(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The hash of the avatar image.  This is used to track changes to the avatar image if the image contents change but the image name remains the same. Use `filesha256("path/to/avatar.png")` whenever possible.
        """
        return pulumi.get(self, "avatar_hash")

    @avatar_hash.setter
    def avatar_hash(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar_hash", value)

    @_builtins.property
    @pulumi.getter(name="avatarUrl")
    def avatar_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the avatar image.
        """
        return pulumi.get(self, "avatar_url")

    @avatar_url.setter
    def avatar_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "avatar_url", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The access token of the user. If this field is omitted, a GitLab token with administrator scope is required to manage the avatar for the specified user. **Note**: the token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("gitlab:index/userAvatar:UserAvatar")
class UserAvatar(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 avatar: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        The `UserAvatar` resource allows users to manage the lifecycle of a user avatar.
        The resource can also be used to set the avatar on project or group access tokens, as well as on service accounts.

        > The `token` attribute is optional only when the GitLab token used by the provider has an administrator scope, as this allows an administrator to manage user avatars.

        > The provided `token` must have the `api` scope in order to set the avatar.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/users/#upload-an-avatar-for-yourself)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_user_avatar`. For example:

        terraform

        import {

          to = gitlab_user_avatar.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        A GitLab User Avatar can be imported using the user id, e.g.

        ```sh
        $ pulumi import gitlab:index/userAvatar:UserAvatar example "12345"
        ```

        NOTE: the `token` and `avatar` resource attributes are not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: the avatar is not available for imported resources.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image.  This is used to track changes to the avatar image if the image contents change but the image name remains the same. Use `filesha256("path/to/avatar.png")` whenever possible.
        :param pulumi.Input[_builtins.str] token: The access token of the user. If this field is omitted, a GitLab token with administrator scope is required to manage the avatar for the specified user. **Note**: the token is not available for imported resources.
        :param pulumi.Input[_builtins.int] user_id: The ID of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserAvatarArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `UserAvatar` resource allows users to manage the lifecycle of a user avatar.
        The resource can also be used to set the avatar on project or group access tokens, as well as on service accounts.

        > The `token` attribute is optional only when the GitLab token used by the provider has an administrator scope, as this allows an administrator to manage user avatars.

        > The provided `token` must have the `api` scope in order to set the avatar.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/users/#upload-an-avatar-for-yourself)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_user_avatar`. For example:

        terraform

        import {

          to = gitlab_user_avatar.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        A GitLab User Avatar can be imported using the user id, e.g.

        ```sh
        $ pulumi import gitlab:index/userAvatar:UserAvatar example "12345"
        ```

        NOTE: the `token` and `avatar` resource attributes are not available for imported resources as this information cannot be read from the GitLab API.

        :param str resource_name: The name of the resource.
        :param UserAvatarArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserAvatarArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 avatar: Optional[pulumi.Input[_builtins.str]] = None,
                 avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserAvatarArgs.__new__(UserAvatarArgs)

            if avatar is None and not opts.urn:
                raise TypeError("Missing required property 'avatar'")
            __props__.__dict__["avatar"] = avatar
            __props__.__dict__["avatar_hash"] = avatar_hash
            __props__.__dict__["token"] = None if token is None else pulumi.Output.secret(token)
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["avatar_url"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(UserAvatar, __self__).__init__(
            'gitlab:index/userAvatar:UserAvatar',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            avatar: Optional[pulumi.Input[_builtins.str]] = None,
            avatar_hash: Optional[pulumi.Input[_builtins.str]] = None,
            avatar_url: Optional[pulumi.Input[_builtins.str]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.int]] = None) -> 'UserAvatar':
        """
        Get an existing UserAvatar resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] avatar: A local path to the avatar image to upload. **Note**: the avatar is not available for imported resources.
        :param pulumi.Input[_builtins.str] avatar_hash: The hash of the avatar image.  This is used to track changes to the avatar image if the image contents change but the image name remains the same. Use `filesha256("path/to/avatar.png")` whenever possible.
        :param pulumi.Input[_builtins.str] avatar_url: The URL of the avatar image.
        :param pulumi.Input[_builtins.str] token: The access token of the user. If this field is omitted, a GitLab token with administrator scope is required to manage the avatar for the specified user. **Note**: the token is not available for imported resources.
        :param pulumi.Input[_builtins.int] user_id: The ID of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserAvatarState.__new__(_UserAvatarState)

        __props__.__dict__["avatar"] = avatar
        __props__.__dict__["avatar_hash"] = avatar_hash
        __props__.__dict__["avatar_url"] = avatar_url
        __props__.__dict__["token"] = token
        __props__.__dict__["user_id"] = user_id
        return UserAvatar(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def avatar(self) -> pulumi.Output[_builtins.str]:
        """
        A local path to the avatar image to upload. **Note**: the avatar is not available for imported resources.
        """
        return pulumi.get(self, "avatar")

    @_builtins.property
    @pulumi.getter(name="avatarHash")
    def avatar_hash(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The hash of the avatar image.  This is used to track changes to the avatar image if the image contents change but the image name remains the same. Use `filesha256("path/to/avatar.png")` whenever possible.
        """
        return pulumi.get(self, "avatar_hash")

    @_builtins.property
    @pulumi.getter(name="avatarUrl")
    def avatar_url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the avatar image.
        """
        return pulumi.get(self, "avatar_url")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The access token of the user. If this field is omitted, a GitLab token with administrator scope is required to manage the avatar for the specified user. **Note**: the token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of the user.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupServiceAccountAccessTokenArgs', 'GroupServiceAccountAccessToken']

@pulumi.input_type
class GroupServiceAccountAccessTokenArgs:
    def __init__(__self__, *,
                 group: pulumi.Input[_builtins.str],
                 scopes: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 user_id: pulumi.Input[_builtins.int],
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rotation_configuration: Optional[pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs']] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a GroupServiceAccountAccessToken resource.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group containing the service account. Must be a top level group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the group service account access token. Valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `self_rotate`, `read_service_ping`. If `self_rotate` is included, you must also provide either `expires_at` or `rotation_configuration`.
        :param pulumi.Input[_builtins.int] user_id: The ID of a service account user.
        :param pulumi.Input[_builtins.str] expires_at: The service account access token expiry date. When left blank, the token follows the standard rule of expiry for personal access tokens.
        :param pulumi.Input[_builtins.str] name: The name of the personal access token.
        :param pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs'] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        pulumi.set(__self__, "group", group)
        pulumi.set(__self__, "scopes", scopes)
        pulumi.set(__self__, "user_id", user_id)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if rotation_configuration is not None:
            pulumi.set(__self__, "rotation_configuration", rotation_configuration)
        if validate_past_expiration_date is not None:
            pulumi.set(__self__, "validate_past_expiration_date", validate_past_expiration_date)

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the group containing the service account. Must be a top level group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        The scopes of the group service account access token. Valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `self_rotate`, `read_service_ping`. If `self_rotate` is included, you must also provide either `expires_at` or `rotation_configuration`.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[_builtins.int]:
        """
        The ID of a service account user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "user_id", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service account access token expiry date. When left blank, the token follows the standard rule of expiry for personal access tokens.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the personal access token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="rotationConfiguration")
    def rotation_configuration(self) -> Optional[pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs']]:
        """
        The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        """
        return pulumi.get(self, "rotation_configuration")

    @rotation_configuration.setter
    def rotation_configuration(self, value: Optional[pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs']]):
        pulumi.set(self, "rotation_configuration", value)

    @_builtins.property
    @pulumi.getter(name="validatePastExpirationDate")
    def validate_past_expiration_date(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Wether to validate if the expiration date is in the future.
        """
        return pulumi.get(self, "validate_past_expiration_date")

    @validate_past_expiration_date.setter
    def validate_past_expiration_date(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validate_past_expiration_date", value)


@pulumi.input_type
class _GroupServiceAccountAccessTokenState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 revoked: Optional[pulumi.Input[_builtins.bool]] = None,
                 rotation_configuration: Optional[pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs']] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.int]] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering GroupServiceAccountAccessToken resources.
        :param pulumi.Input[_builtins.bool] active: True if the token is active.
        :param pulumi.Input[_builtins.str] created_at: Time the token has been created, RFC3339 format.
        :param pulumi.Input[_builtins.str] expires_at: The service account access token expiry date. When left blank, the token follows the standard rule of expiry for personal access tokens.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group containing the service account. Must be a top level group.
        :param pulumi.Input[_builtins.str] name: The name of the personal access token.
        :param pulumi.Input[_builtins.bool] revoked: True if the token is revoked.
        :param pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs'] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the group service account access token. Valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `self_rotate`, `read_service_ping`. If `self_rotate` is included, you must also provide either `expires_at` or `rotation_configuration`.
        :param pulumi.Input[_builtins.str] token: The token of the group service account access token. **Note**: the token is not available for imported resources.
        :param pulumi.Input[_builtins.int] user_id: The ID of a service account user.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if revoked is not None:
            pulumi.set(__self__, "revoked", revoked)
        if rotation_configuration is not None:
            pulumi.set(__self__, "rotation_configuration", rotation_configuration)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)
        if validate_past_expiration_date is not None:
            pulumi.set(__self__, "validate_past_expiration_date", validate_past_expiration_date)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if the token is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Time the token has been created, RFC3339 format.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service account access token expiry date. When left blank, the token follows the standard rule of expiry for personal access tokens.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the group containing the service account. Must be a top level group.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the personal access token.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def revoked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True if the token is revoked.
        """
        return pulumi.get(self, "revoked")

    @revoked.setter
    def revoked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "revoked", value)

    @_builtins.property
    @pulumi.getter(name="rotationConfiguration")
    def rotation_configuration(self) -> Optional[pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs']]:
        """
        The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        """
        return pulumi.get(self, "rotation_configuration")

    @rotation_configuration.setter
    def rotation_configuration(self, value: Optional[pulumi.Input['GroupServiceAccountAccessTokenRotationConfigurationArgs']]):
        pulumi.set(self, "rotation_configuration", value)

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The scopes of the group service account access token. Valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `self_rotate`, `read_service_ping`. If `self_rotate` is included, you must also provide either `expires_at` or `rotation_configuration`.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "scopes", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The token of the group service account access token. **Note**: the token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The ID of a service account user.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "user_id", value)

    @_builtins.property
    @pulumi.getter(name="validatePastExpirationDate")
    def validate_past_expiration_date(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Wether to validate if the expiration date is in the future.
        """
        return pulumi.get(self, "validate_past_expiration_date")

    @validate_past_expiration_date.setter
    def validate_past_expiration_date(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "validate_past_expiration_date", value)


@pulumi.type_token("gitlab:index/groupServiceAccountAccessToken:GroupServiceAccountAccessToken")
class GroupServiceAccountAccessToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rotation_configuration: Optional[pulumi.Input[Union['GroupServiceAccountAccessTokenRotationConfigurationArgs', 'GroupServiceAccountAccessTokenRotationConfigurationArgsDict']]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.int]] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        The `GroupServiceAccountAccessToken` resource allows to manage the lifecycle of a group service account access token.

        > Use of the `timestamp()` function with expires_at will cause the resource to be re-created with every apply, it's recommended to use `plantimestamp()` or a static value instead.

        > Reading the access token status of a service account requires an admin token or a top-level group owner token on gitlab.com. As a result, this resource will ignore permission errors when attempting to read the token status, and will rely on the values in state instead. This can lead to apply-time failures if the token configured for the provider doesn't have permissions to rotate tokens for the service account.

        > Use `rotation_configuration` to automatically rotate tokens instead of using `timestamp()` as timestamp will cause changes with every plan. `pulumi up` must still be run to rotate the token.

        > Due to a limitation in the API, the `rotation_configuration` is unable to set the new expiry date before GitLab 17.9. Instead, when the resource is created, it will default the expiry date to 7 days in the future. On each subsequent apply, the new expiry will be 7 days from the date of the apply.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/service_accounts/#create-a-personal-access-token-for-a-group-service-account)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This must be a top-level group
        example = gitlab.Group("example",
            name="example",
            path="example",
            description="An example group")
        # The service account against the top-level group
        example_sa = gitlab.GroupServiceAccount("example_sa",
            group=example.id,
            name="example-name",
            username="example-username")
        # To assign the service account to a group
        example_membership = gitlab.GroupMembership("example_membership",
            group_id=example.id,
            user_id=example_sa.service_account_id,
            access_level="developer",
            expires_at="2020-03-14")
        # The service account access token with no expiry
        example_sa_token_no_expiry = gitlab.GroupServiceAccountAccessToken("example_sa_token_no_expiry",
            group=example.id,
            user_id=example_sa.service_account_id,
            name="Example service account access token",
            scopes=["api"])
        # The service account access token with expires at
        example_sa_token_expires_at = gitlab.GroupServiceAccountAccessToken("example_sa_token_expires_at",
            group=example.id,
            user_id=example_sa.service_account_id,
            name="Example service account access token",
            expires_at="2020-03-14",
            scopes=["api"])
        # The service account access token with rotation configuration
        example_sa_token_rotation_configuration = gitlab.GroupServiceAccountAccessToken("example_sa_token_rotation_configuration",
            group=example.id,
            user_id=example_sa.service_account_id,
            name="Example service account access token",
            rotation_configuration={
                "rotate_before_days": 2,
                "expiration_days": 7,
            },
            scopes=["api"])
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_service_account_access_token`. For example:

        terraform

        import {

          to = gitlab_group_service_account_access_token.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/groupServiceAccountAccessToken:GroupServiceAccountAccessToken You can import a service account access token using `<resource> <id>`. The
        ```

        `id` is in the form of <group_id>:<service_account_id>:<access_token_id>

        Importing an access token does not import the access token value.

        ```sh
        $ pulumi import gitlab:index/groupServiceAccountAccessToken:GroupServiceAccountAccessToken example 1:2:3
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] expires_at: The service account access token expiry date. When left blank, the token follows the standard rule of expiry for personal access tokens.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group containing the service account. Must be a top level group.
        :param pulumi.Input[_builtins.str] name: The name of the personal access token.
        :param pulumi.Input[Union['GroupServiceAccountAccessTokenRotationConfigurationArgs', 'GroupServiceAccountAccessTokenRotationConfigurationArgsDict']] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the group service account access token. Valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `self_rotate`, `read_service_ping`. If `self_rotate` is included, you must also provide either `expires_at` or `rotation_configuration`.
        :param pulumi.Input[_builtins.int] user_id: The ID of a service account user.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupServiceAccountAccessTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `GroupServiceAccountAccessToken` resource allows to manage the lifecycle of a group service account access token.

        > Use of the `timestamp()` function with expires_at will cause the resource to be re-created with every apply, it's recommended to use `plantimestamp()` or a static value instead.

        > Reading the access token status of a service account requires an admin token or a top-level group owner token on gitlab.com. As a result, this resource will ignore permission errors when attempting to read the token status, and will rely on the values in state instead. This can lead to apply-time failures if the token configured for the provider doesn't have permissions to rotate tokens for the service account.

        > Use `rotation_configuration` to automatically rotate tokens instead of using `timestamp()` as timestamp will cause changes with every plan. `pulumi up` must still be run to rotate the token.

        > Due to a limitation in the API, the `rotation_configuration` is unable to set the new expiry date before GitLab 17.9. Instead, when the resource is created, it will default the expiry date to 7 days in the future. On each subsequent apply, the new expiry will be 7 days from the date of the apply.

        **Upstream API**: [GitLab API docs](https://docs.gitlab.com/api/service_accounts/#create-a-personal-access-token-for-a-group-service-account)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This must be a top-level group
        example = gitlab.Group("example",
            name="example",
            path="example",
            description="An example group")
        # The service account against the top-level group
        example_sa = gitlab.GroupServiceAccount("example_sa",
            group=example.id,
            name="example-name",
            username="example-username")
        # To assign the service account to a group
        example_membership = gitlab.GroupMembership("example_membership",
            group_id=example.id,
            user_id=example_sa.service_account_id,
            access_level="developer",
            expires_at="2020-03-14")
        # The service account access token with no expiry
        example_sa_token_no_expiry = gitlab.GroupServiceAccountAccessToken("example_sa_token_no_expiry",
            group=example.id,
            user_id=example_sa.service_account_id,
            name="Example service account access token",
            scopes=["api"])
        # The service account access token with expires at
        example_sa_token_expires_at = gitlab.GroupServiceAccountAccessToken("example_sa_token_expires_at",
            group=example.id,
            user_id=example_sa.service_account_id,
            name="Example service account access token",
            expires_at="2020-03-14",
            scopes=["api"])
        # The service account access token with rotation configuration
        example_sa_token_rotation_configuration = gitlab.GroupServiceAccountAccessToken("example_sa_token_rotation_configuration",
            group=example.id,
            user_id=example_sa.service_account_id,
            name="Example service account access token",
            rotation_configuration={
                "rotate_before_days": 2,
                "expiration_days": 7,
            },
            scopes=["api"])
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_service_account_access_token`. For example:

        terraform

        import {

          to = gitlab_group_service_account_access_token.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/groupServiceAccountAccessToken:GroupServiceAccountAccessToken You can import a service account access token using `<resource> <id>`. The
        ```

        `id` is in the form of <group_id>:<service_account_id>:<access_token_id>

        Importing an access token does not import the access token value.

        ```sh
        $ pulumi import gitlab:index/groupServiceAccountAccessToken:GroupServiceAccountAccessToken example 1:2:3
        ```

        :param str resource_name: The name of the resource.
        :param GroupServiceAccountAccessTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupServiceAccountAccessTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 rotation_configuration: Optional[pulumi.Input[Union['GroupServiceAccountAccessTokenRotationConfigurationArgs', 'GroupServiceAccountAccessTokenRotationConfigurationArgsDict']]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_id: Optional[pulumi.Input[_builtins.int]] = None,
                 validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupServiceAccountAccessTokenArgs.__new__(GroupServiceAccountAccessTokenArgs)

            __props__.__dict__["expires_at"] = expires_at
            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
            __props__.__dict__["name"] = name
            __props__.__dict__["rotation_configuration"] = rotation_configuration
            if scopes is None and not opts.urn:
                raise TypeError("Missing required property 'scopes'")
            __props__.__dict__["scopes"] = scopes
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["validate_past_expiration_date"] = validate_past_expiration_date
            __props__.__dict__["active"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["revoked"] = None
            __props__.__dict__["token"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(GroupServiceAccountAccessToken, __self__).__init__(
            'gitlab:index/groupServiceAccountAccessToken:GroupServiceAccountAccessToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[_builtins.bool]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            expires_at: Optional[pulumi.Input[_builtins.str]] = None,
            group: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            revoked: Optional[pulumi.Input[_builtins.bool]] = None,
            rotation_configuration: Optional[pulumi.Input[Union['GroupServiceAccountAccessTokenRotationConfigurationArgs', 'GroupServiceAccountAccessTokenRotationConfigurationArgsDict']]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.int]] = None,
            validate_past_expiration_date: Optional[pulumi.Input[_builtins.bool]] = None) -> 'GroupServiceAccountAccessToken':
        """
        Get an existing GroupServiceAccountAccessToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: True if the token is active.
        :param pulumi.Input[_builtins.str] created_at: Time the token has been created, RFC3339 format.
        :param pulumi.Input[_builtins.str] expires_at: The service account access token expiry date. When left blank, the token follows the standard rule of expiry for personal access tokens.
        :param pulumi.Input[_builtins.str] group: The ID or URL-encoded path of the group containing the service account. Must be a top level group.
        :param pulumi.Input[_builtins.str] name: The name of the personal access token.
        :param pulumi.Input[_builtins.bool] revoked: True if the token is revoked.
        :param pulumi.Input[Union['GroupServiceAccountAccessTokenRotationConfigurationArgs', 'GroupServiceAccountAccessTokenRotationConfigurationArgsDict']] rotation_configuration: The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] scopes: The scopes of the group service account access token. Valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `self_rotate`, `read_service_ping`. If `self_rotate` is included, you must also provide either `expires_at` or `rotation_configuration`.
        :param pulumi.Input[_builtins.str] token: The token of the group service account access token. **Note**: the token is not available for imported resources.
        :param pulumi.Input[_builtins.int] user_id: The ID of a service account user.
        :param pulumi.Input[_builtins.bool] validate_past_expiration_date: Wether to validate if the expiration date is in the future.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupServiceAccountAccessTokenState.__new__(_GroupServiceAccountAccessTokenState)

        __props__.__dict__["active"] = active
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["group"] = group
        __props__.__dict__["name"] = name
        __props__.__dict__["revoked"] = revoked
        __props__.__dict__["rotation_configuration"] = rotation_configuration
        __props__.__dict__["scopes"] = scopes
        __props__.__dict__["token"] = token
        __props__.__dict__["user_id"] = user_id
        __props__.__dict__["validate_past_expiration_date"] = validate_past_expiration_date
        return GroupServiceAccountAccessToken(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[_builtins.bool]:
        """
        True if the token is active.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Time the token has been created, RFC3339 format.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[_builtins.str]:
        """
        The service account access token expiry date. When left blank, the token follows the standard rule of expiry for personal access tokens.
        """
        return pulumi.get(self, "expires_at")

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the group containing the service account. Must be a top level group.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the personal access token.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def revoked(self) -> pulumi.Output[_builtins.bool]:
        """
        True if the token is revoked.
        """
        return pulumi.get(self, "revoked")

    @_builtins.property
    @pulumi.getter(name="rotationConfiguration")
    def rotation_configuration(self) -> pulumi.Output[Optional['outputs.GroupServiceAccountAccessTokenRotationConfiguration']]:
        """
        The configuration for when to rotate a token automatically. Will not rotate a token until `pulumi up` is run.
        """
        return pulumi.get(self, "rotation_configuration")

    @_builtins.property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The scopes of the group service account access token. Valid values are: `api`, `read_user`, `read_api`, `read_repository`, `write_repository`, `read_registry`, `write_registry`, `read_virtual_registry`, `write_virtual_registry`, `sudo`, `admin_mode`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `self_rotate`, `read_service_ping`. If `self_rotate` is included, you must also provide either `expires_at` or `rotation_configuration`.
        """
        return pulumi.get(self, "scopes")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[_builtins.str]:
        """
        The token of the group service account access token. **Note**: the token is not available for imported resources.
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.int]:
        """
        The ID of a service account user.
        """
        return pulumi.get(self, "user_id")

    @_builtins.property
    @pulumi.getter(name="validatePastExpirationDate")
    def validate_past_expiration_date(self) -> pulumi.Output[_builtins.bool]:
        """
        Wether to validate if the expiration date is in the future.
        """
        return pulumi.get(self, "validate_past_expiration_date")

